Calculates the density of observations x for state j given the parameters in model. This is used for
the Gaussian emission distribution of a HMM or HSMM and is a suitable prototype for user's to make their own custom distributions.
dnorm.hsmm(x, j, model)A vector of probability densities.
Observed value
State
A hsmmspec or hmmspec object
Jared O'Connell jaredoconnell@gmail.com
This is used by hmm and hsmm to calculate densities for use in the E-step of the EM algorithm.
It can also be used as a template for users wishing to building their own emission distributions