This generates values from a normally distributed emission state j given parameters in model.
rnorm.hsmm(j, model)A single value from the emission distribution.
An integer representing the state
A hmmspec or hsmmspec object
Jared O'Connell jaredoconnell@gmail.com
This is essentially a wrapper for rnorm. Users may build functions with the same
arguments and return values so they can use their own custom emission distributions.